@@ -21,6 +21,13 @@ KEY__sort = "sort"
 KEY__invite_key = "invite_key"
 KEY__parameters = "parameters"
 KEY__template = "template"
+KEY__subject = "subject"
+KEY__recipient = "recipient"
+KEY__filename = "filename"
+KEY__content = "content"
+KEY__attachments = "attachments"
+KEY__app_relative_path = "app_relative_path"
+KEY__sender = "sender"
 KEY__search = "search"
 KEY__application_name = "name"
 KEY__dataset = "dataset"
@@ -35,6 +42,7 @@ KEY__is_node = "is_node"
 KEY__connection = "connection"
 KEY__node = "node"
 KEY__application_url = "url"
+KEY__key = "key"
 KEY__role = "role"
 KEY__mfa_key = "mfa_key"
 KEY__mfa_enabled = "mfa_enabled"
@@ -61,10 +69,27 @@ KEY__jaaql_otp_qr = "jaaql_otp_qr"
 KEY__superjaaql_otp_uri = "superjaaql_otp_uri"
 KEY__superjaaql_otp_qr = "superjaaql_otp_qr"
 KEY__is_public = "is_public"
+KEY__account = "account"
+KEY__encrypted_password = "encrypted_password"
+KEY__email_template_name = "name"
+KEY__column_name = "column_name"
+KEY__table_name = "table_name"
+KEY__is_primary = "is_primary"
+KEY__data_validation_table = "data_validation_table"
+KEY__recipient_validation_view = "recipient_validation_view"
+KEY__email_template = "email_template"
+KEY__do_send_signup_email = "do_send_signup_email"
+KEY__allow_confirm_signup_attempt = "allow_confirm_signup_attempt"
+KEY__already_signed_up_email_template = "already_signed_up_email_template"
+KEY__allow_signup = "allow_signup"
+KEY__email_account_name = "name"
+KEY__email_sent = "sent"
+KEY__body = "body"
 
 ATTR__deleted = "deleted"
 
 HEADER__security = "Authentication-Token"
+HEADER__security_bypass = "Authentication-Token-Bypass"
 
 SQL__where = "WHERE"
 SQL__order_by = "ORDER BY"
@@ -98,12 +123,27 @@ ENCODING__ascii = "ascii"
 EXAMPLE__jwt = "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.e30.yXvILkvUUCBqAFlAv6wQ1Q-QRAjfe3eSosO949U73Vo"
 
 VAULT_KEY__db_crypt_key = "db_crypt_key"
+VAULT_KEY__jaaql_local_access_key = "jaaql_access_key"
 VAULT_KEY__jaaql_lookup_connection = "jaaql_lookup_connection"
 
 ENVIRON__vault_key = "JAAQL_VAULT_PASSWORD"
 ENVIRON__email_credentials = "JAAQL_EMAIL_CREDENTIALS"
 
+EMAIL_PARAM__signup_key = "JAAQL_SIGNUP_KEY"
+
 CONFIG_KEY__server = "SERVER"
 CONFIG_KEY_SERVER__port = "port"
 
-VERSION = "2.12.1"
+JWT_PURPOSE__oauth = "oauth"
+JWT_PURPOSE__pre_auth = "pre_auth"
+JWT_PURPOSE__invite = "invite"
+JWT_PURPOSE__connection = "connection"
+
+NODE__host_node = "host"
+DB__jaaql = "jaaql"
+
+PORT__ems = 6061
+
+ENDPOINT__reload_accounts = "/reload-accounts"
+
+VERSION = "2.13.0"
