@@ -4,6 +4,7 @@ from os.path import join, exists, dirname
 import glob
 from jaaql.constants import DIR__config, FILE__config, CONFIG_KEY__server, CONFIG_KEY_SERVER__port
 from jaaql.db.db_interface import DBInterface
+from jaaql.db.db_utils import create_interface
 from jaaql.constants import VAULT_KEY__jaaql_lookup_connection
 import configparser
 import time
@@ -68,4 +69,4 @@ def await_jaaql_installation(config, is_gunicorn: bool):
 def get_jaaql_connection(config, vault):
     jaaql_uri = vault.get_obj(VAULT_KEY__jaaql_lookup_connection)
     address, port, db, username, password = DBInterface.fracture_uri(jaaql_uri)
-    return DBInterface.create_interface(config, address, port, db, username, password, is_jaaql_user=True)
+    return create_interface(config, address, port, db, username, password, is_jaaql_user=True)
